Documentation
¶
Overview ¶
imgproc package that provides some simple and useful image processing functions.
Index ¶
- func ConvertImageToSlice(img image.Image) []uint8
- func IsGrayscale(img image.Image) bool
- func LoadImage(filePath string) (image.Image, error)
- func LoadMultipleImages(paths []string) ([]image.Image, error)
- func ResizeImage(img image.Image, width int, height int) (image.Image, error)
- func SaveImage(img image.Image, filePath string) error
- func ToGrayscale(img image.Image) image.Image
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConvertImageToSlice ¶
ConvertImageToSlice : convert the image to grayscale and then convert it to a integer slice.
func IsGrayscale ¶
IsGrayscale : check if an image is in grayscale.
func LoadMultipleImages ¶
LoadMultipleImages : load multiple images based on a slice of image paths.
func ResizeImage ¶
ResizeImage : resize the image based on the parameters (maximum size 10.000x10.000).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.